
# Type: predisposes


holds between two entities where exposure to one entity increases the chance of developing the other

URI: [biolink:predisposes](https://w3id.org/biolink/vocab/predisposes)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [affects risk for](affects_risk_for.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | SEMMEDDB:PREDISPOSES |
| **In Subsets:** | | translator_minimal |

